<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://get-tics.com
 * @since      1.0.0
 *
 * @package    Tics
 * @subpackage Tics/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Tics
 * @subpackage Tics/admin
 * @author     Techpaf <contact@get-tics.com>
 */
class Tics_Admin
{

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct($plugin_name, $version)
	{
		add_action('admin_menu', array($this, 'create_plugin_settings_page'));
		// Add Settings and Fields
		add_action('admin_init', array($this, 'setup_sections'));
		add_action('admin_init', array($this, 'setup_fields'));
		$this->plugin_name = $plugin_name;
		$this->version = $version;
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles()
	{

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Tics_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Tics_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/tics-admin.css', array(), $this->version, 'all');
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts()
	{

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Tics_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Tics_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/tics-admin.js', array('jquery'), $this->version, false);
	}
	public function create_plugin_settings_page()
	{
		// Add the menu item and page
		$page_title = 'Tics Manager';
		$menu_title = 'Tics';
		$capability = 'manage_options';
		$slug = 'tics_option';
		$callback = array($this, 'plugin_settings_page_content');
		$icon = 'dashicons-chart-area';
		$position = 100;

		add_menu_page($page_title, $menu_title, $capability, $slug, $callback, $icon, $position);
	}
	public function plugin_settings_page_content()
	{ ?>
		<div class="wrap">
			<h2>Tics Manager</h2>
			<form method="post" action="options.php">
				<?php
				settings_fields('tics_options');
				do_settings_sections('tics_options');
				submit_button();
				?>
			</form>
		</div>
<?php
	}
	public function setup_sections()
	{
		add_settings_section('first_section', 'Change my Tics ID', array($this, 'section_callback'), 'tics_options');
	}
	public function section_callback($arguments)
	{
		switch ($arguments['id']) {
			case 'our_first_section':
				break;
		}
	}
	public function setup_fields()
	{
		$fields = array(
			array(
				'uid' => 'tics_id',
				'label' => 'Your Tics ID',
				'section' => 'first_section',
				'type' => 'text',
				'placeholder' => 'abc123def',
				'helper' => '',
				'supplimental' => 'Find your Tics ID on <a href="https://get-tics.com/app/">Tics Website</a>',
			),
		);
		foreach ($fields as $field) {
			add_settings_field($field['uid'], $field['label'], array($this, 'field_callback'), 'tics_options', $field['section'], $field);
			register_setting('tics_options', $field['uid']);
		}
	}
	public function field_callback($arguments)
	{
		$value = get_option($arguments['uid']); // Get the current value, if there is one
		if (!$value) { // If no value exists
			$value = $arguments['default']; // Set to our default
		}
		echo '<input name="tics_id" id="tics_id" type="text" value="' . get_option('tics_id') . '" /> <br>';
		if ($helper = $arguments['helper']) {
			printf('<span class="helper"> %s</span>', $helper);
		}

		if ($supplimental = $arguments['supplimental']) {
			printf('<p class="description">%s</p>', $supplimental);
		}
	}
}
